#!/usr/bin/env python
# -*- coding: utf-8 -*-

import logging
from django.contrib.auth import get_user_model

from shib_auth.providers import get_provider


logger = logging.getLogger(__name__)


class ShibbolethAuthBackend(object):
    def get_user(self, pk=None):
        User = get_user_model()

        try:
            return User.objects.get(pk=pk)
        except User.DoesNotExist:
            return None

    def authenticate(self, remote_user=None):
        User = get_user_model()

        if not remote_user:
            return None

        try:
            user = User.objects.get(
                username=remote_user,
                is_active=True,
            )
        except User.DoesNotExist:
            return None
        else:
            logging.debug('Authenticating %s', user)
        return user


class ShibbolethUserCreateBackend(object):
    def get_user(self, pk=None):
        User = get_user_model()
        try:
            return User.objects.get(pk=pk)
        except User.DoesNotExist:
            return None

    def authenticate(self, remote_user=None, request=None):
        User = get_user_model()

        if request is None or remote_user is None:
            return None

        is_inactive = User.objects.filter(
            username=remote_user,
            is_active=False
        ).exists()
        if is_inactive:
            return None

        provider = get_provider()
        details = provider(request)
        if not details:
            return None

        user = User.objects.create(
            username=remote_user,
            **details
        )
        if user.is_active:
            return user
        return None
