#!/usr/bin/env python
# -*- coding: utf-8 -*-


import django
from django.contrib import auth
from django.contrib.auth.middleware import RemoteUserMiddleware as BaseRemoteUserMiddleware


class RemoteUserMiddleware(BaseRemoteUserMiddleware):
    header = 'HTTP_REMOTE_USER'

    def process_request(self, request):
        remote_user = request.META.get(self.header)
        if remote_user and request.user.is_authenticated():
            return

        super(RemoteUserMiddleware, self).process_request(request)

        if remote_user and not request.user.is_authenticated():
            user = auth.authenticate(remote_user=remote_user, request=request)
            if user:
                auth.login(request, user)


if django.VERSION > (1, 9):
    class PersistantRemoteUserMiddleware(RemoteUserMiddleware):
        force_logout_if_no_header = False
else:
    class PersistantRemoteUserMiddleware(object):
        def process_request(self, request):
            raise NotImplementedError('PersistantRemoteUserMiddleware requires django > 1.9')
