# -*- coding: utf-8 -*-

from django.db import models

from django.utils.translation import ugettext as _

from django.contrib.auth.models import _user_has_perm, _user_has_module_perms


class UserManager(models.Manager):
    def get_by_natural_key(self, username):
        return self.get(username=username)


class BackendPermissionsMixin(object):
    def has_perm(self, perm, obj=None):
        return _user_has_perm(self, perm, obj)

    def has_perms(self, perm_list, obj=None):
        return all(self.has_perm(perm, obj) for perm in perm_list)

    def has_module_perms(self, app_label):
        return _user_has_module_perms(self, app_label)


class User(BackendPermissionsMixin, models.Model):
    USERNAME_FIELD = 'username'
    REQUIRED_FIELDS = [
        'first_name',
        'last_name',
        'email',
    ]

    objects = UserManager()

    username = models.CharField(
        primary_key=True,
        max_length=255,
    )
    first_name = models.CharField(
        max_length=1000,
    )
    last_name = models.CharField(
        max_length=1000,
    )
    is_active = models.BooleanField(
        default=False,
    )
    email = models.EmailField(
        blank=True,
        null=True,
    )
    last_login = models.DateTimeField(
        _('last login'),
        blank=True,
        null=True
    )
    is_staff = models.BooleanField(
        _('Has access to the admin'),
        default=False,
    )

    @property
    def fullname(self):
        return '{} {}'.format(self.first_name, self.last_name)

    def __repr__(self):
        return '<U {}>'.format(self.username)

    def __str__(self):
        return self.fullname

    def get_username(self):
        return self.username

    def is_authenticated(self):
        return True
